`bagua-core`
=====

[![PyPI version](https://badge.fury.io/py/bagua-core.svg)](https://badge.fury.io/py/bagua-core) [![GitHub license](https://img.shields.io/github/license/BaguaSys/bagua-core)](https://github.com/BaguaSys/bagua-core/blob/master/LICENSE)

The core communication logic for bagua.

* PyPI: https://pypi.org/project/bagua-core/
